@@ -1,4 +1,4 @@
-fast.groupmean <- function( data , group , weights=NULL ){
+fast.groupmean <- function( data , group , weights=NULL , extend=FALSE){
 	groups <- sort( unique( group ) )
 	index.group <- match( group , groups )
 	if ( is.null(weights) ){
@@ -11,6 +11,10 @@ fast.groupmean <- function( data , group , weights=NULL ){
 	colnames(data1) <- colnames(data)
 	data1 <- data1 / Ngroup
 	data1 <- data.frame( "group" = groups , data1 )
+	if (extend){
+	   data1 <- data1[ index.group , ]
+	   rownames(data1) <- NULL
+				}
 	return(data1)
             }
 #.....
@@ -18,7 +22,7 @@ fast.groupmean <- function( data , group , weights=NULL ){
 # extend this function to include weights
 # and calculation of standard deviation and skewness
 #.....
-fast.groupsum <- function( data , group , weights=NULL ){
+fast.groupsum <- function( data , group , weights=NULL , extend=FALSE){
 	groups <- sort( unique( group ) )
 	index.group <- match( group , groups )
 	if ( is.null(weights) ){
@@ -31,5 +35,9 @@ fast.groupsum <- function( data , group , weights=NULL ){
 	colnames(data1) <- colnames(data)
 #	data1 <- data1 / Ngroup
 	data1 <- data.frame( "group" = groups , data1 )
+	if (extend){
+	   data1 <- data1[ index.group , ]
+	   rownames(data1) <- NULL
+				}	
 	return(data1)
             }
\ No newline at end of file
