@@ -2,8 +2,7 @@
 
 ################################################
 # create interactions
-create_interactions <- 
-	function (y_,xobs_,xall_,index_int_,min_int_cor_,maxcols_){ 
+create_interactions <- function (y_,xobs_,xall_,index_int_,min_int_cor_,maxcols_){ 
 	.Call("create_interactions_cpp", 
 		y_,xobs_,xall_,index_int_,min_int_cor_,maxcols_, 
 		PACKAGE = "miceadds")
