@@ -1,5 +1,4 @@
-plausible.value.imputation <-
-function( data , X , Z = NULL, beta0=rep(0,ncol(X)) , sig0=1 ,
+plausible.value.imputation <- function( data , X , Z = NULL, beta0=rep(0,ncol(X)) , sig0=1 ,
                 b = b ,  a = rep(1 , length(b) ) , c = rep(0 , length(b) ),
                 theta.list=seq(-5,5,len=50) , cluster = NULL , 
                 iter , burnin , nplausible=1 , printprogress = TRUE ){
