@@ -1,5 +1,4 @@
-write.pspp <-
-function (data , datafile, pspp.path , decmax=6 ,
+write.pspp <- function (data , datafile, pspp.path , decmax=6 ,
   as.factors=TRUE ,  use.bat=FALSE) {
     data <- as.data.frame(data) 
     df <- data 
